
namespace E {
    public const string AG_SERVICE_TYPE_CALENDAR = "calendar";
    public const string AG_SERVICE_TYPE_CONTACTS = "contacts";
}

namespace E.POAUtils {
    public static bool check_oauth2_support (Ag.AccountService account_service) {
        var mechanism = account_service.get_auth_data ().get_mechanism ();
        if (mechanism == "web_server" || mechanism == "user_agent") {
            return true;
        } else {
            return false;
        }
    }

    /* This is a mapping between AgAccount provider names and
     * ESourceCollection backend names.  It requires knowledge
     * of other registry modules, possibly even from 3rd party
     * packages.
     *
     * FIXME Put the EDS backend name in the .service config
     *       files so we're not hard-coding the providers we
     *       support.  This isn't GNOME Online Accounts. */
    public static string? get_backend_name (string provider) {
        switch (provider) {
            case "google":
                return "google";
            case "microsoft":
                return "outlook";
            case "yahoo":
                return "yahoo";
            default:
                return null;
        }
    }

    /* Determine an appropriate service type based on
     * which extensions are present in the ESource. */
    public static string? get_service_type_from_source (E.Source source) {
        if (source.has_extension (E.SOURCE_EXTENSION_ADDRESS_BOOK))
            return AG_SERVICE_TYPE_CONTACTS;

        if (source.has_extension (E.SOURCE_EXTENSION_CALENDAR))
            return AG_SERVICE_TYPE_CALENDAR;

        if (source.has_extension (E.SOURCE_EXTENSION_MEMO_LIST))
            return AG_SERVICE_TYPE_CALENDAR;

        if (source.has_extension (E.SOURCE_EXTENSION_TASK_LIST))
            return AG_SERVICE_TYPE_CALENDAR;

        return null;
}
}